@@ -6,10 +6,8 @@
 suppressWarnings(suppressMessages({
   library(dplyr)
   library(tidyr)
-  library(rstanarm)
-  library(emmeans)
+  library(magrittr)
 }))
-import::from(magrittr, set_rownames)
 
 context("gather_emmeans_draws")
 
@@ -21,15 +19,18 @@ mtcars_tbl = mtcars %>%
 
 
 test_that("gather_emmeans_draws works on a simple rstanarm model", {
+  skip_if_not_installed("emmeans")
+  skip_if_not_installed("rstanarm")
+
   m_hp_wt = readRDS("../models/models.rstanarm.m_hp_wt.rds")
 
   estimate_grid = list(hp = c(100, 110), wt = 0)
 
-  fits = posterior_linpred(m_hp_wt, newdata = as.data.frame(estimate_grid)) %>%
+  fits = rstanarm::posterior_linpred(m_hp_wt, newdata = as.data.frame(estimate_grid)) %>%
     as.data.frame() %>%
     mutate(
-      .chain = as.integer(NA),
-      .iteration = as.integer(NA),
+      .chain = NA_integer_,
+      .iteration = NA_integer_,
       .draw = seq_len(n())
     ) %>%
     gather(.row, .value, -.chain, -.iteration, -.draw) %>%
@@ -44,7 +45,7 @@ test_that("gather_emmeans_draws works on a simple rstanarm model", {
   # call that created the model (here, the global environment).
   # So we'll specify mtcars_tbl manually using `data =`
   result = m_hp_wt %>%
-    ref_grid(estimate_grid, data = mtcars_tbl) %>%
+    emmeans::ref_grid(estimate_grid, data = mtcars_tbl) %>%
     gather_emmeans_draws()
 
   expect_equal(ref, result)
