@@ -4,14 +4,11 @@
 ###############################################################################
 
 suppressWarnings(suppressMessages({
-  library(bindrcpp)
   library(dplyr)
   library(tidyr)
   library(ggplot2)
-  library(rstan)
-  library(rstanarm)
+  library(magrittr)
 }))
-import::from(magrittr, set_rownames)
 
 context("predicted_draws")
 
@@ -33,13 +30,14 @@ test_that("[add_]predicted_draws throws an error on unsupported models", {
 
 
 test_that("[add_]predicted_draws and basic arguments works on a simple rstanarm model", {
+  skip_if_not_installed("rstanarm")
   m_hp_wt = readRDS("../models/models.rstanarm.m_hp_wt.rds")
 
-  preds = posterior_predict(m_hp_wt, mtcars_tbl, draws = 100, seed = 123) %>%
+  preds = rstanarm::posterior_predict(m_hp_wt, mtcars_tbl, draws = 100, seed = 123) %>%
     as.data.frame() %>%
     mutate(
-      .chain = as.integer(NA),
-      .iteration = as.integer(NA),
+      .chain = NA_integer_,
+      .iteration = NA_integer_,
       .draw = seq_len(n())
     ) %>%
     gather(.row, .prediction, -.chain, -.iteration, -.draw) %>%
@@ -56,13 +54,14 @@ test_that("[add_]predicted_draws and basic arguments works on a simple rstanarm
 
 
 test_that("[add_]predicted_draws and basic arguments works on an rstanarm model with random effects", {
+  skip_if_not_installed("rstanarm")
   m_cyl = readRDS("../models/models.rstanarm.m_cyl.rds")
 
-  preds = posterior_predict(m_cyl, mtcars_tbl, draws = 100, seed = 123) %>%
+  preds = rstanarm::posterior_predict(m_cyl, mtcars_tbl, draws = 100, seed = 123) %>%
     as.data.frame() %>%
     mutate(
-      .chain = as.integer(NA),
-      .iteration = as.integer(NA),
+      .chain = NA_integer_,
+      .iteration = NA_integer_,
       .draw = seq_len(n())
     ) %>%
     gather(.row, .prediction, -.chain, -.iteration, -.draw) %>%
@@ -79,6 +78,7 @@ test_that("[add_]predicted_draws and basic arguments works on an rstanarm model
 
 
 test_that("[add_]predicted_draws works on a simple brms model", {
+  skip_if_not_installed("brms")
   m_hp = readRDS("../models/models.brms.m_hp.rds")
 
   set.seed(123)
@@ -86,8 +86,8 @@ test_that("[add_]predicted_draws works on a simple brms model", {
     as.data.frame() %>%
     set_names(seq_len(ncol(.))) %>%
     mutate(
-      .chain = as.integer(NA),
-      .iteration = as.integer(NA),
+      .chain = NA_integer_,
+      .iteration = NA_integer_,
       .draw = seq_len(n())
     ) %>%
     gather(.row, .prediction, -.chain, -.iteration, -.draw) %>%
@@ -103,6 +103,7 @@ test_that("[add_]predicted_draws works on a simple brms model", {
 })
 
 test_that("[add_]predicted_draws throws an error when nsamples is called instead of n in brms", {
+  skip_if_not_installed("brms")
   m_hp = readRDS("../models/models.brms.m_hp.rds")
 
   expect_error(
@@ -116,6 +117,7 @@ test_that("[add_]predicted_draws throws an error when nsamples is called instead
 })
 
 test_that("[add_]predicted_draws throws an error when draws is called instead of n in rstanarm", {
+  skip_if_not_installed("rstanarm")
   m_hp_wt = readRDS("../models/models.rstanarm.m_hp_wt.rds")
 
   expect_error(
@@ -129,6 +131,7 @@ test_that("[add_]predicted_draws throws an error when draws is called instead of
 })
 
 test_that("[add_]predicted_draws throws an error when re.form is called instead of re_formula in rstanarm", {
+  skip_if_not_installed("rstanarm")
   m_hp_wt = readRDS("../models/models.rstanarm.m_hp_wt.rds")
 
   expect_error(
